@@ -5,6 +5,7 @@
 #
 
 
+import traceback
 from pypykatz import logger
 from pypykatz.commons.common import hexdump
 from unicrypto.symmetric import TDES, AES, MODE_CFB, MODE_CBC
@@ -51,9 +52,17 @@ class LsaDecryptor_NT6(PackageDecryptor):
 
 	def get_IV(self, pos):
 		self.log('Reading IV')
-		#print('Offset to IV: %s' % hex(self.decryptor_template.key_pattern.offset_to_IV_ptr))
+
+		#### TEST!!!!
+		#if hasattr(self.sysinfo, 'IV_OFFSET'):
+		#	ptr_iv = self.reader.get_ptr_with_offset(pos + self.sysinfo.IV_OFFSET)
+		#	self.reader.move(ptr_iv)
+		#	data = self.reader.read(self.decryptor_template.key_pattern.IV_length)
+		#	self.log('IV data: %s' % hexdump(data))
+		#	return data
+		
 		ptr_iv = self.reader.get_ptr_with_offset(pos + self.decryptor_template.key_pattern.offset_to_IV_ptr)
-		self.log('IV pointer takes us to 0x%08x' % ptr_iv)
+		#self.log('IV pointer takes us to 0x%08x' % ptr_iv)
 		self.reader.move(ptr_iv)
 		data = self.reader.read(self.decryptor_template.key_pattern.IV_length)
 		self.log('IV data: %s' % hexdump(data))
