@@ -57,30 +57,23 @@ class LsaTemplate_NT6(PackageTemplate):
 				template = templates['nt5']['x86']['1']
 				
 			elif WindowsMinBuild.WIN_VISTA.value <= sysinfo.buildnumber < WindowsMinBuild.WIN_7.value:
-				#1
 				template = templates['nt6']['x86']['1']
 				
 			elif WindowsMinBuild.WIN_7.value <= sysinfo.buildnumber < WindowsMinBuild.WIN_8.value:
-				#2
 				template = templates['nt6']['x86']['2']
 				
 			elif WindowsMinBuild.WIN_8.value <= sysinfo.buildnumber < WindowsMinBuild.WIN_BLUE.value:
-				#3
 				template = templates['nt6']['x86']['3']
 				
 			elif WindowsMinBuild.WIN_BLUE.value <= sysinfo.buildnumber < WindowsMinBuild.WIN_10.value:
-				#4
 				template = templates['nt6']['x86']['4']
 				
 			elif WindowsMinBuild.WIN_10.value <= sysinfo.buildnumber <= WindowsBuild.WIN_10_1507.value:
-				#5
 				template = templates['nt6']['x86']['5']				
 				
 			elif WindowsBuild.WIN_10_1507.value > sysinfo.buildnumber < WindowsBuild.WIN_10_1909.value:
-				#6
 				template = templates['nt6']['x86']['6']
 			else:
-				#7
 				template = templates['nt6']['x86']['7']
 		
 		elif sysinfo.architecture == KatzSystemArchitecture.X64:
@@ -92,92 +85,29 @@ class LsaTemplate_NT6(PackageTemplate):
 			
 			elif sysinfo.buildnumber < WindowsMinBuild.WIN_7.value:
 				#vista
-				#1
 				template = templates['nt6']['x64']['1']
-				#key_pattern = LSADecyptorKeyPattern()
-				#key_pattern.signature = b'\x83\x64\x24\x30\x00\x44\x8b\x4c\x24\x48\x48\x8b\x0d'
-				#key_pattern.IV_length = 16
-				#key_pattern.offset_to_IV_ptr = 63
-				#key_pattern.offset_to_DES_key_ptr = -69
-				#key_pattern.offset_to_AES_key_ptr = 25
-				#
-				#template.key_pattern = key_pattern
-				#template.key_struct = KIWI_BCRYPT_KEY
-				#template.key_handle_struct = KIWI_BCRYPT_HANDLE_KEY
 		
 			elif sysinfo.buildnumber < WindowsMinBuild.WIN_8.value:
 				#win 7
-				#2
 				template = templates['nt6']['x64']['2']
-
-				#key_pattern = LSADecyptorKeyPattern()
-				#key_pattern.signature = b'\x83\x64\x24\x30\x00\x44\x8b\x4c\x24\x48\x48\x8b\x0d'
-				#key_pattern.IV_length = 16
-				#key_pattern.offset_to_IV_ptr = 59
-				#key_pattern.offset_to_DES_key_ptr = -61
-				#key_pattern.offset_to_AES_key_ptr = 25
-				#
-				#template.key_pattern = key_pattern
-				#template.key_struct = KIWI_BCRYPT_KEY
-				#template.key_handle_struct = KIWI_BCRYPT_HANDLE_KEY
 			
 			elif sysinfo.buildnumber < WindowsMinBuild.WIN_10.value:
 				#win 8 and blue
-				#3
-				#key_pattern = LSADecyptorKeyPattern()
-				#key_pattern.signature = b'\x83\x64\x24\x30\x00\x44\x8b\x4d\xd8\x48\x8b\x0d'
-				#key_pattern.IV_length = 16
-				#key_pattern.offset_to_IV_ptr = 62
-				#key_pattern.offset_to_DES_key_ptr = -70
-				#key_pattern.offset_to_AES_key_ptr = 23
-				
 				if sysinfo.buildnumber < WindowsMinBuild.WIN_BLUE.value:
-					template = templates['nt6']['x64']['3']
-					#win8
-					#3
-					#template.key_pattern = key_pattern
-					#template.key_struct = KIWI_BCRYPT_KEY8
-					#template.key_handle_struct = KIWI_BCRYPT_HANDLE_KEY
-				
+					if sysinfo.msv_dll_timestamp < 0x60000000:
+						template = templates['nt6']['x64']['3']
+					else:
+						template = templates['nt6']['x64']['7']				
 				else:
 					template = templates['nt6']['x64']['4']
-					#4
 					#win blue
-					#template.key_pattern = key_pattern
-					#template.key_struct = KIWI_BCRYPT_KEY81
-					#template.key_handle_struct = KIWI_BCRYPT_HANDLE_KEY
-			
 			
 			elif sysinfo.buildnumber < WindowsBuild.WIN_10_1809.value:
-				template = templates['nt6']['x64']['5']
-				#5
-				#key_pattern = LSADecyptorKeyPattern()
-				#key_pattern.signature = b'\x83\x64\x24\x30\x00\x48\x8d\x45\xe0\x44\x8b\x4d\xd8\x48\x8d\x15'
-				#key_pattern.IV_length = 16
-				#key_pattern.offset_to_IV_ptr = 61
-				#key_pattern.offset_to_DES_key_ptr = -73
-				#key_pattern.offset_to_AES_key_ptr = 16
-				#
-				#template.key_pattern = key_pattern
-				#template.key_struct = KIWI_BCRYPT_KEY81
-				#template.key_handle_struct = KIWI_BCRYPT_HANDLE_KEY				
-				
+				template = templates['nt6']['x64']['5']			
 				
 			#elif sysinfo.buildnumber <= WindowsBuild.WIN_10_1809.value:
 			else:
 				template = templates['nt6']['x64']['6']
-				#1809
-				#6
-				#key_pattern = LSADecyptorKeyPattern()
-				#key_pattern.signature = b'\x83\x64\x24\x30\x00\x48\x8d\x45\xe0\x44\x8b\x4d\xd8\x48\x8d\x15'
-				#key_pattern.IV_length = 16
-				#key_pattern.offset_to_IV_ptr = 67
-				#key_pattern.offset_to_DES_key_ptr = -89
-				#key_pattern.offset_to_AES_key_ptr = 16
-				#
-				#template.key_pattern = key_pattern
-				#template.key_struct = KIWI_BCRYPT_KEY81
-				#template.key_handle_struct = KIWI_BCRYPT_HANDLE_KEY
 			
 		else:
 			raise Exception('Missing LSA decrpytor template for Architecture: %s , Build number %s' % (sysinfo.architecture, sysinfo.buildnumber))
@@ -342,7 +272,7 @@ class LSA_x64_4(LsaTemplate_NT6):
 		self.key_pattern.offset_to_AES_key_ptr = 23
 		
 		self.key_struct = KIWI_BCRYPT_KEY81
-		self.key_handle_struct = KIWI_BCRYPT_HANDLE_KEY				
+		self.key_handle_struct = KIWI_BCRYPT_HANDLE_KEY
 
 class LSA_x64_5(LsaTemplate_NT6):
 	def __init__(self):
@@ -370,6 +300,19 @@ class LSA_x64_6(LsaTemplate_NT6):
 		self.key_struct = KIWI_BCRYPT_KEY81
 		self.key_handle_struct = KIWI_BCRYPT_HANDLE_KEY
 
+class LSA_x64_7(LsaTemplate_NT6):
+	def __init__(self):
+		LsaTemplate_NT6.__init__(self)
+		self.key_pattern = LSADecyptorKeyPattern()
+		self.key_pattern.signature = b'\x83\x64\x24\x30\x00\x44\x8b\x4d\xd8\x48\x8b\x0d'
+		self.key_pattern.IV_length = 16
+		self.key_pattern.offset_to_IV_ptr = 58
+		self.key_pattern.offset_to_DES_key_ptr = -62
+		self.key_pattern.offset_to_AES_key_ptr = 23
+		
+		self.key_struct = KIWI_BCRYPT_KEY8
+		self.key_handle_struct = KIWI_BCRYPT_HANDLE_KEY
+
 class LSA_x86_1(LsaTemplate_NT6):
 	def __init__(self):
 		LsaTemplate_NT6.__init__(self)
@@ -473,6 +416,7 @@ templates = {
 			'4' : LSA_x64_4(),
 			'5' : LSA_x64_5(),
 			'6' : LSA_x64_6(),
+			'7' : LSA_x64_7(),
 		},
 		'x86': {
 			'1' : LSA_x86_1(),
